import * as React from 'react';
import { IgrTemplateColumn, HeaderClickAction,
         IgrTemplateCellUpdatingEventArgs, IgrTemplateCellInfo,
         IgrGridColumnOptionsModule, IgrTextColumn, IgrDataGrid,
         IgrDataGridModule } from 'igniteui-react-grids';

IgrDataGridModule.register();
IgrGridColumnOptionsModule.register();

export default class DataGridColumnSorting extends React.Component<any, any> {

    public data: any[];
    public grid: IgrDataGrid;

    constructor(props: any) {
        super(props);
        this.onGridRef = this.onGridRef.bind(this);        
        this.onPriorityCellUpdating = this.onPriorityCellUpdating.bind(this);

        this.data = [];

        for (let i = 0; i < 10; i++) {

            let number = this.getRandomNumber(1, 3);

            let priority: string;

            if (number == 1) {
                priority = "High";
            }
            else if (number == 2) {
                priority = "Medium";
            }
            else {
                priority = "Low";
            }

            this.data.push({ ID: i, Label: "Item " + i.toString(), Priority: priority, PrioritySort: number });
        }
    }

    public render(): JSX.Element {
        return (
            <div className="igContainer">
                <IgrDataGrid
                    height="calc(100% - 40px)"
                    width="100%"
                    headerClickAction={HeaderClickAction.SortByOneColumnOnly}                    
                    autoGenerateColumns="false"
                    dataSource={this.data}
                    defaultColumnMinWidth={100}                    
                    isColumnOptionsEnabled="true"
                    ref={this.onGridRef}>
                    <IgrTextColumn field="ID" width="*>110" horizontalAlignment="center" />
                    <IgrTextColumn field="Label" headerText="Property" width="*>150" />
                    <IgrTemplateColumn field="PrioritySort" headerText="Priority" cellUpdating={this.onPriorityCellUpdating} />
                </IgrDataGrid>
            </div>
        );
    }

    public onGridRef(grid: IgrDataGrid) {
        this.grid = grid;
    }

    public onPriorityCellUpdating(s: IgrTemplateColumn, e: IgrTemplateCellUpdatingEventArgs) {
        const content = e.content as HTMLDivElement;
        let span1: HTMLSpanElement | null = null;        
        const info = e.cellInfo as IgrTemplateCellInfo;
        const item = info.rowItem;

        if (content.childElementCount === 0) {

            span1 = document.createElement("span");
            content.style.fontFamily = "Segoe UI";
            content.style.fontSize = "13px";
            content.style.verticalAlign = "center";
            content.style.lineHeight = "normal";
            content.style.display = "flex";
            content.style.flexDirection = "column";
            content.style.justifyContent = "center";
            content.style.height = "100%";
            content.style.width = "100%";
            content.appendChild(span1);            
        }
        else {
            span1 = content.children[0] as HTMLSpanElement;        
        }

        if (span1) {
            span1.textContent = item.Priority;            
        }
    }

    private getRandomNumber(min: number, max: number): number {
        return Math.round(min + Math.random() * (max - min));
    }
}
